@@ -14,19 +14,12 @@ class UserProfileForm(forms.ModelForm):
     error_css_class = 'form-field-error'
     required_css_class = 'form-field-required'
 
-    def __init__(self, user=None, *args, **kwargs):
-        self.user = user
-        super(UserProfileForm, self).__init__(**kwargs)
+    def __init__(self, *args, **kwargs):
+        super(UserProfileForm, self).__init__(*args, **kwargs)
         for field in get_user_model().REQUIRED_FIELDS:
             if field in self.fields:
                 self.fields[field].required = True
 
-    def save(self, commit=True):
-        instance = super(UserProfileForm, self).save(commit=False)
-        instance.user = self.user
-        if commit:
-            instance.save()
-        return instance
 
     class Meta:
         model = User
@@ -37,4 +30,19 @@ class UserProfileForm(forms.ModelForm):
                     and field_name != 'email' ]
 
 class EmailChangeForm(forms.Form):
+    password = forms.CharField(label=_("Password"),
+                               widget=forms.PasswordInput)
     email = forms.EmailField(label=_('New email'))
+
+    def __init__(self, user, *args, **kwargs):
+        self.user = user
+        super(EmailChangeForm, self).__init__(*args, **kwargs)
+
+    def clean_password(self):
+        password = self.cleaned_data["password"]
+        if not self.user.check_password(password):
+            raise forms.ValidationError(
+                _('Incorrect password.'),
+                code='password_incorrect',
+            )
+        return password
