@@ -2,13 +2,14 @@ import logging
 import random
 import datetime
 import string
+from xml.etree import ElementTree as ET
 
 from django.http import HttpResponseRedirect, HttpResponseBadRequest, \
-    HttpResponse
+    HttpResponse, HttpResponseNotAllowed
 from django.core.urlresolvers import reverse
 from django.contrib.auth.views import redirect_to_login, logout
 from django.utils.http import urlquote, urlencode
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 from django.conf import settings
 
 from models import CasTicket
@@ -19,12 +20,51 @@ from constants import SERVICE_PARAM, RENEW_PARAM, GATEWAY_PARAM, ID_PARAM, \
     CANCEL_PARAM, SERVICE_TICKET_PREFIX, TICKET_PARAM, \
     CAS10_VALIDATION_FAILURE, CAS10_VALIDATION_SUCCESS, PGT_URL_PARAM, \
     INVALID_REQUEST_ERROR, INVALID_TICKET_ERROR, INVALID_SERVICE_ERROR, \
-    INTERNAL_ERROR, CAS20_VALIDATION_FAILURE, CAS20_VALIDATION_SUCCESS
+    INTERNAL_ERROR, CAS20_VALIDATION_FAILURE, CAS20_VALIDATION_SUCCESS, \
+    CAS_NAMESPACE, USER_ELT, SERVICE_RESPONSE_ELT, AUTHENTICATION_SUCCESS_ELT
 
 logger = logging.getLogger('authentic2.idp.idp_cas')
 
 ALPHABET = string.letters+string.digits+'-'
 
+SAML_RESPONSE_TEMPLATE = '''<?xml version="1.0" encoding="UTF-8"?>
+<SOAP-ENV:Envelope SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
+<SOAP-ENV:Header/>
+<SOAP-ENV:Body>
+<Response xmlns="urn:oasis:names:tc:SAML:1.0:protocol" xmlns:saml="urn:oasis:names:tc:SAML:1.0:assertion" xmlns:samlp="urn:oasis:names:tc:SAML:1.0:protocol" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" IssueInstant="2013-05-16T16:07:35Z" MajorVersion="1" MinorVersion="1" Recipient="https://amonecole.monreseau.lan/webcalendar/login.php" ResponseID="{reponse_id}">
+  <Status>
+    <StatusCode Value="samlp:Success">
+    </StatusCode>
+  </Status>
+  <Assertion xmlns="urn:oasis:names:tc:SAML:1.0:assertion" AssertionID="{assertion_id}" IssueInstant="{issue_instant}" Issuer="{issuer}" MajorVersion="1" MinorVersion="1">
+<Conditions NotBefore="{not_before}" NotOnOrAfter="{not_on_or_after}">
+      <AudienceRestrictionCondition>
+        <Audience>{audience}</Audience>
+      </AudienceRestrictionCondition>
+    </Conditions>
+    <AttributeStatement>
+      <Subject>
+        <NameIdentifier>{name_id}</NameIdentifier>
+        <SubjectConfirmation>
+          <ConfirmationMethod>urn:oasis:names:tc:SAML:1.0:cm:artifact</ConfirmationMethod>
+        </SubjectConfirmation>
+      </Subject>
+      {attributes}
+
+    </AttributeStatement>
+    <AuthenticationStatement AuthenticationInstant="{authentication_instant}" AuthenticationMethod="{authentication_method}">
+      <Subject>
+        <NameIdentifier>{name_id}</NameIdentifier>
+        <SubjectConfirmation>
+          <ConfirmationMethod>urn:oasis:names:tc:SAML:1.0:cm:artifact</ConfirmationMethod>
+        </SubjectConfirmation>
+      </Subject>
+    </AuthenticationStatement>
+  </Assertion>
+</Response>
+</SOAP-ENV:Body>
+</SOAP-ENV:Envelope>'''
+
 class CasProvider(object):
     def get_url(self):
         return patterns('cas',
@@ -32,6 +72,7 @@ class CasProvider(object):
                 url('^continue$', self.continue_cas),
                 url('^validate$', self.validate),
                 url('^serviceValidate$', self.service_validate),
+                url('^samlValidate$', self.saml_validate),
                 url('^logout$', self.logout))
     url = property(get_url)
 
@@ -189,8 +230,10 @@ renew:%s and gateway:%s' % (service, renew, gateway))
             return self.return_ticket(request, st)
 
     def return_ticket(self, request, st):
-        return HttpResponseRedirect('%s?ticket=%s' % (st.service,
-            st.ticket_id))
+        if '?' in st.service:
+            return HttpResponseRedirect('%s&ticket=%s' % (st.service,st.ticket_id))
+        else:
+            return HttpResponseRedirect('%s?ticket=%s' % (st.service,st.ticket_id))
 
     def validate(self, request):
         if request.method != 'GET':
@@ -222,7 +265,79 @@ renew:%s and gateway:%s' % (service, renew, gateway))
 
     def cas20_error(self, request, code):
         message = self.get_cas20_error_message(code)
-        return HttpResponse(CAS20_VALIDATION_FAILURE % (code, message))
+        return HttpResponse(CAS20_VALIDATION_FAILURE % (code, message),
+                content_type='text/xml')
+
+    def get_attributes(self, request, st):
+        # XXX: st.service contains the requesting service URL, use it to match CAS attribute policy
+        return {}, False
+
+    def saml_build_attributes(self, request, st):
+        attributes, section = self.get_attributes(request, st)
+        result = []
+        for key, value in attributes.iteritems():
+            key = key.encode('utf-8')
+            value = value.encode('utf-8')
+            result.append('''<Attribute AttributeName="{key}" AttributeNamespace="http://www.ja-sig.org/products/cas/">
+<AttributeValue>{value}</AttributeValue>
+</Attribute>'''.format(key=key, value=value))
+        return ''.join(result)
+
+    def saml_validate(self, request):
+        if request.method != 'POST':
+            return HttpResponseNotAllowed(['POST'])
+        root = ET.fromstring(request.body)
+        ns = dict(
+            SOAP_ENV = 'http://schemas.xmlsoap.org/soap/envelope/',
+            samlp = 'urn:oasis:names:tc:SAML:1.0:protocol')
+        if root.tag != '{%(SOAP_ENV)s}Envelope' % ns:
+            return self.saml_error(request, INVALID_REQUEST_ERROR)
+        assertion_artifact = root.find('{%(SOAP_ENV)s}Body/{%(samlp)s}Request/{%(samlp)s}AssertionArtifact')
+        ticket = assertion_artifact.text
+        try:
+            st = CasTicket.objects.get(ticket_id=ticket)
+            st.delete()
+        except CasTicket.DoesNotExist:
+            st = None
+        if st is None or not st.valid():
+            return self.saml_error(request, INVALID_TICKET_ERROR)
+        new_id = self.generate_id()
+
+        ctx = {
+                'response_id': new_id,
+                'assertion_id': new_id,
+                'issue_instant': '', # XXX: iso time
+                'issuer': request.build_absolute_uri('/'),
+                'not_before': '', # XXX: issue time - lag
+                'not_on_or_after': '', # XXX issue time + lag,
+                'audience': st.service.encode('utf-8'),
+                'name_id': request.user.username,
+                'attributes': self.saml_build_attributes(request, st),
+        }
+        return HttpResponse(SAML_RESPONSE_TEMPLATE.format(**ctx),
+                content_type='text/xml')
+
+    def service_validate_success_response(self, request, st):
+        attributes, section = self.get_attributes(request, st)
+        try:
+            ET.register_namespace('cas', 'http://www.yale.edu/tp/cas')
+        except AttributeError:
+            ET._namespace_map['http://www.yale.edu/tp/cas'] = 'cas'
+        root = ET.Element('{%s}%s' % (CAS_NAMESPACE, SERVICE_RESPONSE_ELT))
+        success = ET.SubElement(root, '{%s}%s' % (CAS_NAMESPACE, AUTHENTICATION_SUCCESS_ELT))
+        if attributes:
+            if section == 'default':
+                user = success
+            else:
+                user = ET.SubElement(success, '{%s}%s' % (CAS_NAMESPACE, section))
+            for key, value in attributes.iteritems():
+                elt = ET.SubElement(user, '{%s}%s' % (CAS_NAMESPACE, key))
+                elt.text = unicode(value)
+        else:
+            user = ET.SubElement(success, '{%s}%s' % (CAS_NAMESPACE, USER_ELT))
+            user.text = unicode(st.user)
+        return HttpResponse(ET.tostring(root, encoding='utf8'),
+                content_type='text/xml')
 
     def service_validate(self, request):
         '''
@@ -255,8 +370,9 @@ renew:%s and gateway:%s' % (service, renew, gateway))
             if pgt_url:
                 raise NotImplementedError(
                         'CAS 2.0 pgtUrl parameter is not handled')
-            return HttpResponse(CAS20_VALIDATION_SUCCESS % st.user)
+            return self.service_validate_success_response(request, st)
         except Exception:
+            logger.exception('error in cas:service_validate')
             return self.cas20_error(INTERNAL_ERROR)
 
     def logout(self, request):
