@@ -1,7 +1,5 @@
-from django.conf.urls.defaults import *
-from django.views.generic.simple import direct_to_template
-import saml.saml2_endpoints
-import saml.idff12_endpoints
+from django.conf.urls import patterns, include
+
 from django.conf import settings
 from interactions import consent_federation, consent_attributes
 
@@ -9,7 +7,7 @@ urlpatterns = patterns('',)
 
 if settings.IDP_SAML2:
     urlpatterns += patterns('',
-        (r'^saml2/', include(saml.saml2_endpoints)),)
+        (r'^saml2/', include('authentic2.idp.saml.urls')),)
 
 if settings.IDP_CAS:
     from authentic2.idp.idp_cas.views import Authentic2CasProvider
